"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_ContainerService(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MANAGED_CLUSTERS_FIELD_NUMBER: builtins.int
    MANAGED_CLUSTERS_AGENT_POOLS_FIELD_NUMBER: builtins.int
    @property
    def managed_clusters(self) -> global___ManagedClusters: ...
    @property
    def managed_clusters_agent_pools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedClustersAgentPools]: ...
    def __init__(
        self,
        *,
        managed_clusters: global___ManagedClusters | None = ...,
        managed_clusters_agent_pools: collections.abc.Iterable[global___ManagedClustersAgentPools] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["managed_clusters", b"managed_clusters"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["managed_clusters", b"managed_clusters", "managed_clusters_agent_pools", b"managed_clusters_agent_pools"]) -> None: ...

global___Microsoft_ContainerService = Microsoft_ContainerService

@typing_extensions.final
class Snapshots(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CREATION_DATA_FIELD_NUMBER: builtins.int
    SNAPSHOT_TYPE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    @property
    def creation_data(self) -> global___CreationData: ...
    snapshot_type: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        creation_data: global___CreationData | None = ...,
        snapshot_type: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["creation_data", b"creation_data", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_data", b"creation_data", "location", b"location", "name", b"name", "resource_info", b"resource_info", "snapshot_type", b"snapshot_type", "tags", b"tags"]) -> None: ...

global___Snapshots = Snapshots

@typing_extensions.final
class ManagedClustersPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def private_endpoint(self) -> global___PrivateEndpoint: ...
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkServiceConnectionState: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        private_endpoint: global___PrivateEndpoint | None = ...,
        private_link_service_connection_state: global___PrivateLinkServiceConnectionState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> None: ...

global___ManagedClustersPrivateEndpointConnections = ManagedClustersPrivateEndpointConnections

@typing_extensions.final
class PrivateLinkServiceConnectionState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    description: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "status", b"status"]) -> None: ...

global___PrivateLinkServiceConnectionState = PrivateLinkServiceConnectionState

@typing_extensions.final
class PrivateEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___PrivateEndpoint = PrivateEndpoint

@typing_extensions.final
class ManagedClustersMaintenanceConfigurations(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NOT_ALLOWED_TIME_FIELD_NUMBER: builtins.int
    TIME_IN_WEEK_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def not_allowed_time(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TimeSpan]: ...
    @property
    def time_in_week(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TimeInWeek]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        not_allowed_time: collections.abc.Iterable[global___TimeSpan] | None = ...,
        time_in_week: collections.abc.Iterable[global___TimeInWeek] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "not_allowed_time", b"not_allowed_time", "resource_info", b"resource_info", "time_in_week", b"time_in_week"]) -> None: ...

global___ManagedClustersMaintenanceConfigurations = ManagedClustersMaintenanceConfigurations

@typing_extensions.final
class TimeInWeek(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAY_FIELD_NUMBER: builtins.int
    HOUR_SLOTS_FIELD_NUMBER: builtins.int
    day: builtins.str
    @property
    def hour_slots(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        day: builtins.str = ...,
        hour_slots: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["day", b"day", "hour_slots", b"hour_slots"]) -> None: ...

global___TimeInWeek = TimeInWeek

@typing_extensions.final
class TimeSpan(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    END_FIELD_NUMBER: builtins.int
    START_FIELD_NUMBER: builtins.int
    end: builtins.str
    start: builtins.str
    def __init__(
        self,
        *,
        end: builtins.str = ...,
        start: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["end", b"end", "start", b"start"]) -> None: ...

global___TimeSpan = TimeSpan

@typing_extensions.final
class ManagedClustersAgentPools(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class NodeLabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AVAILABILITY_ZONES_FIELD_NUMBER: builtins.int
    CAPACITY_RESERVATION_GROUP_ID_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    CREATION_DATA_FIELD_NUMBER: builtins.int
    ENABLE_AUTO_SCALING_FIELD_NUMBER: builtins.int
    ENABLE_ENCRYPTION_AT_HOST_FIELD_NUMBER: builtins.int
    ENABLE_FIPS_FIELD_NUMBER: builtins.int
    ENABLE_NODE_PUBLIC_IP_FIELD_NUMBER: builtins.int
    ENABLE_ULTRA_SSD_FIELD_NUMBER: builtins.int
    GPU_INSTANCE_PROFILE_FIELD_NUMBER: builtins.int
    HOST_GROUP_ID_FIELD_NUMBER: builtins.int
    KUBELET_CONFIG_FIELD_NUMBER: builtins.int
    KUBELET_DISK_TYPE_FIELD_NUMBER: builtins.int
    LINUX_OS_CONFIG_FIELD_NUMBER: builtins.int
    MAX_COUNT_FIELD_NUMBER: builtins.int
    MAX_PODS_FIELD_NUMBER: builtins.int
    MESSAGE_OF_THE_DAY_FIELD_NUMBER: builtins.int
    MIN_COUNT_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    NODE_LABELS_FIELD_NUMBER: builtins.int
    NODE_PUBLIC_IP_PREFIX_ID_FIELD_NUMBER: builtins.int
    NODE_TAINTS_FIELD_NUMBER: builtins.int
    ORCHESTRATOR_VERSION_FIELD_NUMBER: builtins.int
    OS_DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    OS_DISK_TYPE_FIELD_NUMBER: builtins.int
    OS_SKU_FIELD_NUMBER: builtins.int
    OS_TYPE_FIELD_NUMBER: builtins.int
    POD_SUBNET_ID_FIELD_NUMBER: builtins.int
    POWER_STATE_FIELD_NUMBER: builtins.int
    PROXIMITY_PLACEMENT_GROUP_ID_FIELD_NUMBER: builtins.int
    SCALE_DOWN_MODE_FIELD_NUMBER: builtins.int
    SCALE_SET_EVICTION_POLICY_FIELD_NUMBER: builtins.int
    SCALE_SET_PRIORITY_FIELD_NUMBER: builtins.int
    SPOT_MAX_PRICE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    UPGRADE_SETTINGS_FIELD_NUMBER: builtins.int
    VM_SIZE_FIELD_NUMBER: builtins.int
    VNET_SUBNET_ID_FIELD_NUMBER: builtins.int
    WORKLOAD_RUNTIME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def availability_zones(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    capacity_reservation_group_id: builtins.str
    count: builtins.int
    @property
    def creation_data(self) -> global___CreationData: ...
    enable_auto_scaling: builtins.bool
    enable_encryption_at_host: builtins.bool
    enable_fips: builtins.bool
    enable_node_public_ip: builtins.bool
    enable_ultra_ssd: builtins.bool
    gpu_instance_profile: builtins.str
    host_group_id: builtins.str
    @property
    def kubelet_config(self) -> global___KubeletConfig: ...
    kubelet_disk_type: builtins.str
    @property
    def linux_os_config(self) -> global___LinuxOSConfig: ...
    max_count: builtins.int
    max_pods: builtins.int
    message_of_the_day: builtins.str
    min_count: builtins.int
    mode: builtins.str
    @property
    def node_labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    node_public_ip_prefix_id: builtins.str
    @property
    def node_taints(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    orchestrator_version: builtins.str
    os_disk_size_gb: builtins.int
    os_disk_type: builtins.str
    os_sku: builtins.str
    os_type: builtins.str
    pod_subnet_id: builtins.str
    @property
    def power_state(self) -> global___PowerState: ...
    proximity_placement_group_id: builtins.str
    scale_down_mode: builtins.str
    scale_set_eviction_policy: builtins.str
    scale_set_priority: builtins.str
    spot_max_price: builtins.float
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    type: builtins.str
    @property
    def upgrade_settings(self) -> global___AgentPoolUpgradeSettings: ...
    vm_size: builtins.str
    vnet_subnet_id: builtins.str
    workload_runtime: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        availability_zones: collections.abc.Iterable[builtins.str] | None = ...,
        capacity_reservation_group_id: builtins.str = ...,
        count: builtins.int = ...,
        creation_data: global___CreationData | None = ...,
        enable_auto_scaling: builtins.bool = ...,
        enable_encryption_at_host: builtins.bool = ...,
        enable_fips: builtins.bool = ...,
        enable_node_public_ip: builtins.bool = ...,
        enable_ultra_ssd: builtins.bool = ...,
        gpu_instance_profile: builtins.str = ...,
        host_group_id: builtins.str = ...,
        kubelet_config: global___KubeletConfig | None = ...,
        kubelet_disk_type: builtins.str = ...,
        linux_os_config: global___LinuxOSConfig | None = ...,
        max_count: builtins.int = ...,
        max_pods: builtins.int = ...,
        message_of_the_day: builtins.str = ...,
        min_count: builtins.int = ...,
        mode: builtins.str = ...,
        node_labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        node_public_ip_prefix_id: builtins.str = ...,
        node_taints: collections.abc.Iterable[builtins.str] | None = ...,
        orchestrator_version: builtins.str = ...,
        os_disk_size_gb: builtins.int = ...,
        os_disk_type: builtins.str = ...,
        os_sku: builtins.str = ...,
        os_type: builtins.str = ...,
        pod_subnet_id: builtins.str = ...,
        power_state: global___PowerState | None = ...,
        proximity_placement_group_id: builtins.str = ...,
        scale_down_mode: builtins.str = ...,
        scale_set_eviction_policy: builtins.str = ...,
        scale_set_priority: builtins.str = ...,
        spot_max_price: builtins.float = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        type: builtins.str = ...,
        upgrade_settings: global___AgentPoolUpgradeSettings | None = ...,
        vm_size: builtins.str = ...,
        vnet_subnet_id: builtins.str = ...,
        workload_runtime: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["creation_data", b"creation_data", "kubelet_config", b"kubelet_config", "linux_os_config", b"linux_os_config", "power_state", b"power_state", "resource_info", b"resource_info", "upgrade_settings", b"upgrade_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["availability_zones", b"availability_zones", "capacity_reservation_group_id", b"capacity_reservation_group_id", "count", b"count", "creation_data", b"creation_data", "enable_auto_scaling", b"enable_auto_scaling", "enable_encryption_at_host", b"enable_encryption_at_host", "enable_fips", b"enable_fips", "enable_node_public_ip", b"enable_node_public_ip", "enable_ultra_ssd", b"enable_ultra_ssd", "gpu_instance_profile", b"gpu_instance_profile", "host_group_id", b"host_group_id", "kubelet_config", b"kubelet_config", "kubelet_disk_type", b"kubelet_disk_type", "linux_os_config", b"linux_os_config", "max_count", b"max_count", "max_pods", b"max_pods", "message_of_the_day", b"message_of_the_day", "min_count", b"min_count", "mode", b"mode", "name", b"name", "node_labels", b"node_labels", "node_public_ip_prefix_id", b"node_public_ip_prefix_id", "node_taints", b"node_taints", "orchestrator_version", b"orchestrator_version", "os_disk_size_gb", b"os_disk_size_gb", "os_disk_type", b"os_disk_type", "os_sku", b"os_sku", "os_type", b"os_type", "pod_subnet_id", b"pod_subnet_id", "power_state", b"power_state", "proximity_placement_group_id", b"proximity_placement_group_id", "resource_info", b"resource_info", "scale_down_mode", b"scale_down_mode", "scale_set_eviction_policy", b"scale_set_eviction_policy", "scale_set_priority", b"scale_set_priority", "spot_max_price", b"spot_max_price", "tags", b"tags", "type", b"type", "upgrade_settings", b"upgrade_settings", "vm_size", b"vm_size", "vnet_subnet_id", b"vnet_subnet_id", "workload_runtime", b"workload_runtime"]) -> None: ...

global___ManagedClustersAgentPools = ManagedClustersAgentPools

@typing_extensions.final
class ManagedClusters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AddonProfilesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class IdentityProfileEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EXTENDED_LOCATION_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AAD_PROFILE_FIELD_NUMBER: builtins.int
    ADDON_PROFILES_FIELD_NUMBER: builtins.int
    AGENT_POOL_PROFILES_FIELD_NUMBER: builtins.int
    API_SERVER_ACCESS_PROFILE_FIELD_NUMBER: builtins.int
    AUTO_SCALER_PROFILE_FIELD_NUMBER: builtins.int
    AUTO_UPGRADE_PROFILE_FIELD_NUMBER: builtins.int
    DISABLE_LOCAL_ACCOUNTS_FIELD_NUMBER: builtins.int
    DISK_ENCRYPTION_SET_ID_FIELD_NUMBER: builtins.int
    DNS_PREFIX_FIELD_NUMBER: builtins.int
    ENABLE_NAMESPACE_RESOURCES_FIELD_NUMBER: builtins.int
    ENABLE_POD_SECURITY_POLICY_FIELD_NUMBER: builtins.int
    ENABLE_RBAC_FIELD_NUMBER: builtins.int
    FQDN_SUBDOMAIN_FIELD_NUMBER: builtins.int
    HTTP_PROXY_CONFIG_FIELD_NUMBER: builtins.int
    IDENTITY_PROFILE_FIELD_NUMBER: builtins.int
    KUBERNETES_VERSION_FIELD_NUMBER: builtins.int
    LINUX_PROFILE_FIELD_NUMBER: builtins.int
    NETWORK_PROFILE_FIELD_NUMBER: builtins.int
    NODE_RESOURCE_GROUP_FIELD_NUMBER: builtins.int
    OIDC_ISSUER_PROFILE_FIELD_NUMBER: builtins.int
    POD_IDENTITY_PROFILE_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_RESOURCES_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    SECURITY_PROFILE_FIELD_NUMBER: builtins.int
    SERVICE_PRINCIPAL_PROFILE_FIELD_NUMBER: builtins.int
    WINDOWS_PROFILE_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    MANAGED_CLUSTERS_MAINTENANCE_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    MANAGED_CLUSTERS_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def extended_location(self) -> global___ExtendedLocation: ...
    @property
    def identity(self) -> global___ManagedClusterIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def aad_profile(self) -> global___ManagedClusterAADProfile: ...
    @property
    def addon_profiles(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def agent_pool_profiles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedClusterAgentPoolProfile]: ...
    @property
    def api_server_access_profile(self) -> global___ManagedClusterAPIServerAccessProfile: ...
    @property
    def auto_scaler_profile(self) -> global___ManagedClusterPropertiesAutoScalerProfile: ...
    @property
    def auto_upgrade_profile(self) -> global___ManagedClusterAutoUpgradeProfile: ...
    disable_local_accounts: builtins.bool
    disk_encryption_set_id: builtins.str
    dns_prefix: builtins.str
    enable_namespace_resources: builtins.bool
    enable_pod_security_policy: builtins.bool
    enable_rbac: builtins.bool
    fqdn_subdomain: builtins.str
    @property
    def http_proxy_config(self) -> global___ManagedClusterHTTPProxyConfig: ...
    @property
    def identity_profile(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    kubernetes_version: builtins.str
    @property
    def linux_profile(self) -> global___ContainerServiceLinuxProfile: ...
    @property
    def network_profile(self) -> global___ContainerServiceNetworkProfile: ...
    node_resource_group: builtins.str
    @property
    def oidc_issuer_profile(self) -> global___ManagedClusterOIDCIssuerProfile: ...
    @property
    def pod_identity_profile(self) -> global___ManagedClusterPodIdentityProfile: ...
    @property
    def private_link_resources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateLinkResource]: ...
    public_network_access: builtins.str
    @property
    def security_profile(self) -> global___ManagedClusterSecurityProfile: ...
    @property
    def service_principal_profile(self) -> global___ManagedClusterServicePrincipalProfile: ...
    @property
    def windows_profile(self) -> global___ManagedClusterWindowsProfile: ...
    @property
    def sku(self) -> global___ManagedClusterSKU: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def managed_clusters_maintenance_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedClustersMaintenanceConfigurations]: ...
    @property
    def managed_clusters_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedClustersPrivateEndpointConnections]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        extended_location: global___ExtendedLocation | None = ...,
        identity: global___ManagedClusterIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        aad_profile: global___ManagedClusterAADProfile | None = ...,
        addon_profiles: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        agent_pool_profiles: collections.abc.Iterable[global___ManagedClusterAgentPoolProfile] | None = ...,
        api_server_access_profile: global___ManagedClusterAPIServerAccessProfile | None = ...,
        auto_scaler_profile: global___ManagedClusterPropertiesAutoScalerProfile | None = ...,
        auto_upgrade_profile: global___ManagedClusterAutoUpgradeProfile | None = ...,
        disable_local_accounts: builtins.bool = ...,
        disk_encryption_set_id: builtins.str = ...,
        dns_prefix: builtins.str = ...,
        enable_namespace_resources: builtins.bool = ...,
        enable_pod_security_policy: builtins.bool = ...,
        enable_rbac: builtins.bool = ...,
        fqdn_subdomain: builtins.str = ...,
        http_proxy_config: global___ManagedClusterHTTPProxyConfig | None = ...,
        identity_profile: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        kubernetes_version: builtins.str = ...,
        linux_profile: global___ContainerServiceLinuxProfile | None = ...,
        network_profile: global___ContainerServiceNetworkProfile | None = ...,
        node_resource_group: builtins.str = ...,
        oidc_issuer_profile: global___ManagedClusterOIDCIssuerProfile | None = ...,
        pod_identity_profile: global___ManagedClusterPodIdentityProfile | None = ...,
        private_link_resources: collections.abc.Iterable[global___PrivateLinkResource] | None = ...,
        public_network_access: builtins.str = ...,
        security_profile: global___ManagedClusterSecurityProfile | None = ...,
        service_principal_profile: global___ManagedClusterServicePrincipalProfile | None = ...,
        windows_profile: global___ManagedClusterWindowsProfile | None = ...,
        sku: global___ManagedClusterSKU | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        managed_clusters_maintenance_configurations: collections.abc.Iterable[global___ManagedClustersMaintenanceConfigurations] | None = ...,
        managed_clusters_private_endpoint_connections: collections.abc.Iterable[global___ManagedClustersPrivateEndpointConnections] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aad_profile", b"aad_profile", "api_server_access_profile", b"api_server_access_profile", "auto_scaler_profile", b"auto_scaler_profile", "auto_upgrade_profile", b"auto_upgrade_profile", "extended_location", b"extended_location", "http_proxy_config", b"http_proxy_config", "identity", b"identity", "linux_profile", b"linux_profile", "network_profile", b"network_profile", "oidc_issuer_profile", b"oidc_issuer_profile", "pod_identity_profile", b"pod_identity_profile", "resource_info", b"resource_info", "security_profile", b"security_profile", "service_principal_profile", b"service_principal_profile", "sku", b"sku", "windows_profile", b"windows_profile"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aad_profile", b"aad_profile", "addon_profiles", b"addon_profiles", "agent_pool_profiles", b"agent_pool_profiles", "api_server_access_profile", b"api_server_access_profile", "auto_scaler_profile", b"auto_scaler_profile", "auto_upgrade_profile", b"auto_upgrade_profile", "disable_local_accounts", b"disable_local_accounts", "disk_encryption_set_id", b"disk_encryption_set_id", "dns_prefix", b"dns_prefix", "enable_namespace_resources", b"enable_namespace_resources", "enable_pod_security_policy", b"enable_pod_security_policy", "enable_rbac", b"enable_rbac", "extended_location", b"extended_location", "fqdn_subdomain", b"fqdn_subdomain", "http_proxy_config", b"http_proxy_config", "identity", b"identity", "identity_profile", b"identity_profile", "kubernetes_version", b"kubernetes_version", "linux_profile", b"linux_profile", "location", b"location", "managed_clusters_maintenance_configurations", b"managed_clusters_maintenance_configurations", "managed_clusters_private_endpoint_connections", b"managed_clusters_private_endpoint_connections", "name", b"name", "network_profile", b"network_profile", "node_resource_group", b"node_resource_group", "oidc_issuer_profile", b"oidc_issuer_profile", "pod_identity_profile", b"pod_identity_profile", "private_link_resources", b"private_link_resources", "public_network_access", b"public_network_access", "resource_info", b"resource_info", "security_profile", b"security_profile", "service_principal_profile", b"service_principal_profile", "sku", b"sku", "tags", b"tags", "windows_profile", b"windows_profile"]) -> None: ...

global___ManagedClusters = ManagedClusters

@typing_extensions.final
class ManagedClusterSKU(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    name: builtins.str
    tier: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        tier: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "tier", b"tier"]) -> None: ...

global___ManagedClusterSKU = ManagedClusterSKU

@typing_extensions.final
class ManagedClusterWindowsProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADMIN_PASSWORD_FIELD_NUMBER: builtins.int
    ADMIN_USERNAME_FIELD_NUMBER: builtins.int
    ENABLE_CS_IPROXY_FIELD_NUMBER: builtins.int
    GMSA_PROFILE_FIELD_NUMBER: builtins.int
    LICENSE_TYPE_FIELD_NUMBER: builtins.int
    admin_password: builtins.str
    admin_username: builtins.str
    enable_cs_iproxy: builtins.bool
    @property
    def gmsa_profile(self) -> global___WindowsGmsaProfile: ...
    license_type: builtins.str
    def __init__(
        self,
        *,
        admin_password: builtins.str = ...,
        admin_username: builtins.str = ...,
        enable_cs_iproxy: builtins.bool = ...,
        gmsa_profile: global___WindowsGmsaProfile | None = ...,
        license_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gmsa_profile", b"gmsa_profile"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["admin_password", b"admin_password", "admin_username", b"admin_username", "enable_cs_iproxy", b"enable_cs_iproxy", "gmsa_profile", b"gmsa_profile", "license_type", b"license_type"]) -> None: ...

global___ManagedClusterWindowsProfile = ManagedClusterWindowsProfile

@typing_extensions.final
class WindowsGmsaProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_SERVER_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    ROOT_DOMAIN_NAME_FIELD_NUMBER: builtins.int
    dns_server: builtins.str
    enabled: builtins.bool
    root_domain_name: builtins.str
    def __init__(
        self,
        *,
        dns_server: builtins.str = ...,
        enabled: builtins.bool = ...,
        root_domain_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dns_server", b"dns_server", "enabled", b"enabled", "root_domain_name", b"root_domain_name"]) -> None: ...

global___WindowsGmsaProfile = WindowsGmsaProfile

@typing_extensions.final
class ManagedClusterServicePrincipalProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_ID_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    client_id: builtins.str
    secret: builtins.str
    def __init__(
        self,
        *,
        client_id: builtins.str = ...,
        secret: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_id", b"client_id", "secret", b"secret"]) -> None: ...

global___ManagedClusterServicePrincipalProfile = ManagedClusterServicePrincipalProfile

@typing_extensions.final
class ManagedClusterSecurityProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AZURE_DEFENDER_FIELD_NUMBER: builtins.int
    @property
    def azure_defender(self) -> global___ManagedClusterSecurityProfileAzureDefender: ...
    def __init__(
        self,
        *,
        azure_defender: global___ManagedClusterSecurityProfileAzureDefender | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["azure_defender", b"azure_defender"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["azure_defender", b"azure_defender"]) -> None: ...

global___ManagedClusterSecurityProfile = ManagedClusterSecurityProfile

@typing_extensions.final
class ManagedClusterSecurityProfileAzureDefender(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    LOG_ANALYTICS_WORKSPACE_RESOURCE_ID_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    log_analytics_workspace_resource_id: builtins.str
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        log_analytics_workspace_resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "log_analytics_workspace_resource_id", b"log_analytics_workspace_resource_id"]) -> None: ...

global___ManagedClusterSecurityProfileAzureDefender = ManagedClusterSecurityProfileAzureDefender

@typing_extensions.final
class PrivateLinkResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    REQUIRED_MEMBERS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    group_id: builtins.str
    id: builtins.str
    name: builtins.str
    @property
    def required_members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    type: builtins.str
    def __init__(
        self,
        *,
        group_id: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        required_members: collections.abc.Iterable[builtins.str] | None = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["group_id", b"group_id", "id", b"id", "name", b"name", "required_members", b"required_members", "type", b"type"]) -> None: ...

global___PrivateLinkResource = PrivateLinkResource

@typing_extensions.final
class ManagedClusterPodIdentityProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_NETWORK_PLUGIN_KUBENET_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITY_EXCEPTIONS_FIELD_NUMBER: builtins.int
    allow_network_plugin_kubenet: builtins.bool
    enabled: builtins.bool
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedClusterPodIdentity]: ...
    @property
    def user_assigned_identity_exceptions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedClusterPodIdentityException]: ...
    def __init__(
        self,
        *,
        allow_network_plugin_kubenet: builtins.bool = ...,
        enabled: builtins.bool = ...,
        user_assigned_identities: collections.abc.Iterable[global___ManagedClusterPodIdentity] | None = ...,
        user_assigned_identity_exceptions: collections.abc.Iterable[global___ManagedClusterPodIdentityException] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_network_plugin_kubenet", b"allow_network_plugin_kubenet", "enabled", b"enabled", "user_assigned_identities", b"user_assigned_identities", "user_assigned_identity_exceptions", b"user_assigned_identity_exceptions"]) -> None: ...

global___ManagedClusterPodIdentityProfile = ManagedClusterPodIdentityProfile

@typing_extensions.final
class ManagedClusterPodIdentityException(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PodLabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    POD_LABELS_FIELD_NUMBER: builtins.int
    name: builtins.str
    namespace: builtins.str
    @property
    def pod_labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        namespace: builtins.str = ...,
        pod_labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "namespace", b"namespace", "pod_labels", b"pod_labels"]) -> None: ...

global___ManagedClusterPodIdentityException = ManagedClusterPodIdentityException

@typing_extensions.final
class ManagedClusterPodIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BINDING_SELECTOR_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    binding_selector: builtins.str
    @property
    def identity(self) -> global___UserAssignedIdentity: ...
    name: builtins.str
    namespace: builtins.str
    def __init__(
        self,
        *,
        binding_selector: builtins.str = ...,
        identity: global___UserAssignedIdentity | None = ...,
        name: builtins.str = ...,
        namespace: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["binding_selector", b"binding_selector", "identity", b"identity", "name", b"name", "namespace", b"namespace"]) -> None: ...

global___ManagedClusterPodIdentity = ManagedClusterPodIdentity

@typing_extensions.final
class UserAssignedIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_ID_FIELD_NUMBER: builtins.int
    OBJECT_ID_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    client_id: builtins.str
    object_id: builtins.str
    resource_id: builtins.str
    def __init__(
        self,
        *,
        client_id: builtins.str = ...,
        object_id: builtins.str = ...,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_id", b"client_id", "object_id", b"object_id", "resource_id", b"resource_id"]) -> None: ...

global___UserAssignedIdentity = UserAssignedIdentity

@typing_extensions.final
class ManagedClusterOIDCIssuerProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled"]) -> None: ...

global___ManagedClusterOIDCIssuerProfile = ManagedClusterOIDCIssuerProfile

@typing_extensions.final
class ContainerServiceNetworkProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_SERVICE_IP_FIELD_NUMBER: builtins.int
    DOCKER_BRIDGE_CIDR_FIELD_NUMBER: builtins.int
    IP_FAMILIES_FIELD_NUMBER: builtins.int
    LOAD_BALANCER_PROFILE_FIELD_NUMBER: builtins.int
    LOAD_BALANCER_SKU_FIELD_NUMBER: builtins.int
    NAT_GATEWAY_PROFILE_FIELD_NUMBER: builtins.int
    NETWORK_MODE_FIELD_NUMBER: builtins.int
    NETWORK_PLUGIN_FIELD_NUMBER: builtins.int
    NETWORK_POLICY_FIELD_NUMBER: builtins.int
    OUTBOUND_TYPE_FIELD_NUMBER: builtins.int
    POD_CIDR_FIELD_NUMBER: builtins.int
    POD_CIDRS_FIELD_NUMBER: builtins.int
    SERVICE_CIDR_FIELD_NUMBER: builtins.int
    SERVICE_CIDRS_FIELD_NUMBER: builtins.int
    dns_service_ip: builtins.str
    docker_bridge_cidr: builtins.str
    @property
    def ip_families(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def load_balancer_profile(self) -> global___ManagedClusterLoadBalancerProfile: ...
    load_balancer_sku: builtins.str
    @property
    def nat_gateway_profile(self) -> global___ManagedClusterNATGatewayProfile: ...
    network_mode: builtins.str
    network_plugin: builtins.str
    network_policy: builtins.str
    outbound_type: builtins.str
    pod_cidr: builtins.str
    @property
    def pod_cidrs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    service_cidr: builtins.str
    @property
    def service_cidrs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        dns_service_ip: builtins.str = ...,
        docker_bridge_cidr: builtins.str = ...,
        ip_families: collections.abc.Iterable[builtins.str] | None = ...,
        load_balancer_profile: global___ManagedClusterLoadBalancerProfile | None = ...,
        load_balancer_sku: builtins.str = ...,
        nat_gateway_profile: global___ManagedClusterNATGatewayProfile | None = ...,
        network_mode: builtins.str = ...,
        network_plugin: builtins.str = ...,
        network_policy: builtins.str = ...,
        outbound_type: builtins.str = ...,
        pod_cidr: builtins.str = ...,
        pod_cidrs: collections.abc.Iterable[builtins.str] | None = ...,
        service_cidr: builtins.str = ...,
        service_cidrs: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["load_balancer_profile", b"load_balancer_profile", "nat_gateway_profile", b"nat_gateway_profile"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dns_service_ip", b"dns_service_ip", "docker_bridge_cidr", b"docker_bridge_cidr", "ip_families", b"ip_families", "load_balancer_profile", b"load_balancer_profile", "load_balancer_sku", b"load_balancer_sku", "nat_gateway_profile", b"nat_gateway_profile", "network_mode", b"network_mode", "network_plugin", b"network_plugin", "network_policy", b"network_policy", "outbound_type", b"outbound_type", "pod_cidr", b"pod_cidr", "pod_cidrs", b"pod_cidrs", "service_cidr", b"service_cidr", "service_cidrs", b"service_cidrs"]) -> None: ...

global___ContainerServiceNetworkProfile = ContainerServiceNetworkProfile

@typing_extensions.final
class ManagedClusterNATGatewayProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_OUTBOUND_IPS_FIELD_NUMBER: builtins.int
    IDLE_TIMEOUT_IN_MINUTES_FIELD_NUMBER: builtins.int
    MANAGED_OUTBOUND_IP_PROFILE_FIELD_NUMBER: builtins.int
    @property
    def effective_outbound_ips(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResourceReference]: ...
    idle_timeout_in_minutes: builtins.int
    @property
    def managed_outbound_ip_profile(self) -> global___ManagedClusterManagedOutboundIPProfile: ...
    def __init__(
        self,
        *,
        effective_outbound_ips: collections.abc.Iterable[global___ResourceReference] | None = ...,
        idle_timeout_in_minutes: builtins.int = ...,
        managed_outbound_ip_profile: global___ManagedClusterManagedOutboundIPProfile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["managed_outbound_ip_profile", b"managed_outbound_ip_profile"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["effective_outbound_ips", b"effective_outbound_ips", "idle_timeout_in_minutes", b"idle_timeout_in_minutes", "managed_outbound_ip_profile", b"managed_outbound_ip_profile"]) -> None: ...

global___ManagedClusterNATGatewayProfile = ManagedClusterNATGatewayProfile

@typing_extensions.final
class ManagedClusterManagedOutboundIPProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    count: builtins.int
    def __init__(
        self,
        *,
        count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count"]) -> None: ...

global___ManagedClusterManagedOutboundIPProfile = ManagedClusterManagedOutboundIPProfile

@typing_extensions.final
class ManagedClusterLoadBalancerProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOCATED_OUTBOUND_PORTS_FIELD_NUMBER: builtins.int
    EFFECTIVE_OUTBOUND_IPS_FIELD_NUMBER: builtins.int
    ENABLE_MULTIPLE_STANDARD_LOAD_BALANCERS_FIELD_NUMBER: builtins.int
    IDLE_TIMEOUT_IN_MINUTES_FIELD_NUMBER: builtins.int
    MANAGED_OUTBOUND_IPS_FIELD_NUMBER: builtins.int
    OUTBOUND_IP_PREFIXES_FIELD_NUMBER: builtins.int
    OUTBOUND_IPS_FIELD_NUMBER: builtins.int
    allocated_outbound_ports: builtins.int
    @property
    def effective_outbound_ips(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResourceReference]: ...
    enable_multiple_standard_load_balancers: builtins.bool
    idle_timeout_in_minutes: builtins.int
    @property
    def managed_outbound_ips(self) -> global___ManagedClusterLoadBalancerProfileManagedOutboundIPs: ...
    @property
    def outbound_ip_prefixes(self) -> global___ManagedClusterLoadBalancerProfileOutboundIPPrefixes: ...
    @property
    def outbound_ips(self) -> global___ManagedClusterLoadBalancerProfileOutboundIPs: ...
    def __init__(
        self,
        *,
        allocated_outbound_ports: builtins.int = ...,
        effective_outbound_ips: collections.abc.Iterable[global___ResourceReference] | None = ...,
        enable_multiple_standard_load_balancers: builtins.bool = ...,
        idle_timeout_in_minutes: builtins.int = ...,
        managed_outbound_ips: global___ManagedClusterLoadBalancerProfileManagedOutboundIPs | None = ...,
        outbound_ip_prefixes: global___ManagedClusterLoadBalancerProfileOutboundIPPrefixes | None = ...,
        outbound_ips: global___ManagedClusterLoadBalancerProfileOutboundIPs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["managed_outbound_ips", b"managed_outbound_ips", "outbound_ip_prefixes", b"outbound_ip_prefixes", "outbound_ips", b"outbound_ips"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allocated_outbound_ports", b"allocated_outbound_ports", "effective_outbound_ips", b"effective_outbound_ips", "enable_multiple_standard_load_balancers", b"enable_multiple_standard_load_balancers", "idle_timeout_in_minutes", b"idle_timeout_in_minutes", "managed_outbound_ips", b"managed_outbound_ips", "outbound_ip_prefixes", b"outbound_ip_prefixes", "outbound_ips", b"outbound_ips"]) -> None: ...

global___ManagedClusterLoadBalancerProfile = ManagedClusterLoadBalancerProfile

@typing_extensions.final
class ManagedClusterLoadBalancerProfileOutboundIPs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBLIC_IPS_FIELD_NUMBER: builtins.int
    @property
    def public_ips(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResourceReference]: ...
    def __init__(
        self,
        *,
        public_ips: collections.abc.Iterable[global___ResourceReference] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["public_ips", b"public_ips"]) -> None: ...

global___ManagedClusterLoadBalancerProfileOutboundIPs = ManagedClusterLoadBalancerProfileOutboundIPs

@typing_extensions.final
class ManagedClusterLoadBalancerProfileOutboundIPPrefixes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBLIC_IP_PREFIXES_FIELD_NUMBER: builtins.int
    @property
    def public_ip_prefixes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResourceReference]: ...
    def __init__(
        self,
        *,
        public_ip_prefixes: collections.abc.Iterable[global___ResourceReference] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["public_ip_prefixes", b"public_ip_prefixes"]) -> None: ...

global___ManagedClusterLoadBalancerProfileOutboundIPPrefixes = ManagedClusterLoadBalancerProfileOutboundIPPrefixes

@typing_extensions.final
class ManagedClusterLoadBalancerProfileManagedOutboundIPs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    COUNT_IPV6_FIELD_NUMBER: builtins.int
    count: builtins.int
    count_ipv6: builtins.int
    def __init__(
        self,
        *,
        count: builtins.int = ...,
        count_ipv6: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count", "count_ipv6", b"count_ipv6"]) -> None: ...

global___ManagedClusterLoadBalancerProfileManagedOutboundIPs = ManagedClusterLoadBalancerProfileManagedOutboundIPs

@typing_extensions.final
class ResourceReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___ResourceReference = ResourceReference

@typing_extensions.final
class ContainerServiceLinuxProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADMIN_USERNAME_FIELD_NUMBER: builtins.int
    SSH_FIELD_NUMBER: builtins.int
    admin_username: builtins.str
    @property
    def ssh(self) -> global___ContainerServiceSshConfiguration: ...
    def __init__(
        self,
        *,
        admin_username: builtins.str = ...,
        ssh: global___ContainerServiceSshConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ssh", b"ssh"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["admin_username", b"admin_username", "ssh", b"ssh"]) -> None: ...

global___ContainerServiceLinuxProfile = ContainerServiceLinuxProfile

@typing_extensions.final
class ContainerServiceSshConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBLIC_KEYS_FIELD_NUMBER: builtins.int
    @property
    def public_keys(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContainerServiceSshPublicKey]: ...
    def __init__(
        self,
        *,
        public_keys: collections.abc.Iterable[global___ContainerServiceSshPublicKey] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["public_keys", b"public_keys"]) -> None: ...

global___ContainerServiceSshConfiguration = ContainerServiceSshConfiguration

@typing_extensions.final
class ContainerServiceSshPublicKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_DATA_FIELD_NUMBER: builtins.int
    key_data: builtins.str
    def __init__(
        self,
        *,
        key_data: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_data", b"key_data"]) -> None: ...

global___ContainerServiceSshPublicKey = ContainerServiceSshPublicKey

@typing_extensions.final
class ManagedClusterHTTPProxyConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_PROXY_FIELD_NUMBER: builtins.int
    HTTPS_PROXY_FIELD_NUMBER: builtins.int
    NO_PROXY_FIELD_NUMBER: builtins.int
    TRUSTED_CA_FIELD_NUMBER: builtins.int
    http_proxy: builtins.str
    https_proxy: builtins.str
    @property
    def no_proxy(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    trusted_ca: builtins.str
    def __init__(
        self,
        *,
        http_proxy: builtins.str = ...,
        https_proxy: builtins.str = ...,
        no_proxy: collections.abc.Iterable[builtins.str] | None = ...,
        trusted_ca: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["http_proxy", b"http_proxy", "https_proxy", b"https_proxy", "no_proxy", b"no_proxy", "trusted_ca", b"trusted_ca"]) -> None: ...

global___ManagedClusterHTTPProxyConfig = ManagedClusterHTTPProxyConfig

@typing_extensions.final
class ManagedClusterAutoUpgradeProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPGRADE_CHANNEL_FIELD_NUMBER: builtins.int
    upgrade_channel: builtins.str
    def __init__(
        self,
        *,
        upgrade_channel: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["upgrade_channel", b"upgrade_channel"]) -> None: ...

global___ManagedClusterAutoUpgradeProfile = ManagedClusterAutoUpgradeProfile

@typing_extensions.final
class ManagedClusterPropertiesAutoScalerProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BALANCE_SIMILAR_NODE_GROUPS_FIELD_NUMBER: builtins.int
    EXPANDER_FIELD_NUMBER: builtins.int
    MAX_EMPTY_BULK_DELETE_FIELD_NUMBER: builtins.int
    MAX_GRACEFUL_TERMINATION_SEC_FIELD_NUMBER: builtins.int
    MAX_NODE_PROVISION_TIME_FIELD_NUMBER: builtins.int
    MAX_TOTAL_UNREADY_PERCENTAGE_FIELD_NUMBER: builtins.int
    NEW_POD_SCALE_UP_DELAY_FIELD_NUMBER: builtins.int
    OK_TOTAL_UNREADY_COUNT_FIELD_NUMBER: builtins.int
    SCALE_DOWN_DELAY_AFTER_ADD_FIELD_NUMBER: builtins.int
    SCALE_DOWN_DELAY_AFTER_DELETE_FIELD_NUMBER: builtins.int
    SCALE_DOWN_DELAY_AFTER_FAILURE_FIELD_NUMBER: builtins.int
    SCALE_DOWN_UNNEEDED_TIME_FIELD_NUMBER: builtins.int
    SCALE_DOWN_UNREADY_TIME_FIELD_NUMBER: builtins.int
    SCALE_DOWN_UTILIZATION_THRESHOLD_FIELD_NUMBER: builtins.int
    SCAN_INTERVAL_FIELD_NUMBER: builtins.int
    SKIP_NODES_WITH_LOCAL_STORAGE_FIELD_NUMBER: builtins.int
    SKIP_NODES_WITH_SYSTEM_PODS_FIELD_NUMBER: builtins.int
    balance_similar_node_groups: builtins.str
    expander: builtins.str
    max_empty_bulk_delete: builtins.str
    max_graceful_termination_sec: builtins.str
    max_node_provision_time: builtins.str
    max_total_unready_percentage: builtins.str
    new_pod_scale_up_delay: builtins.str
    ok_total_unready_count: builtins.str
    scale_down_delay_after_add: builtins.str
    scale_down_delay_after_delete: builtins.str
    scale_down_delay_after_failure: builtins.str
    scale_down_unneeded_time: builtins.str
    scale_down_unready_time: builtins.str
    scale_down_utilization_threshold: builtins.str
    scan_interval: builtins.str
    skip_nodes_with_local_storage: builtins.str
    skip_nodes_with_system_pods: builtins.str
    def __init__(
        self,
        *,
        balance_similar_node_groups: builtins.str = ...,
        expander: builtins.str = ...,
        max_empty_bulk_delete: builtins.str = ...,
        max_graceful_termination_sec: builtins.str = ...,
        max_node_provision_time: builtins.str = ...,
        max_total_unready_percentage: builtins.str = ...,
        new_pod_scale_up_delay: builtins.str = ...,
        ok_total_unready_count: builtins.str = ...,
        scale_down_delay_after_add: builtins.str = ...,
        scale_down_delay_after_delete: builtins.str = ...,
        scale_down_delay_after_failure: builtins.str = ...,
        scale_down_unneeded_time: builtins.str = ...,
        scale_down_unready_time: builtins.str = ...,
        scale_down_utilization_threshold: builtins.str = ...,
        scan_interval: builtins.str = ...,
        skip_nodes_with_local_storage: builtins.str = ...,
        skip_nodes_with_system_pods: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["balance_similar_node_groups", b"balance_similar_node_groups", "expander", b"expander", "max_empty_bulk_delete", b"max_empty_bulk_delete", "max_graceful_termination_sec", b"max_graceful_termination_sec", "max_node_provision_time", b"max_node_provision_time", "max_total_unready_percentage", b"max_total_unready_percentage", "new_pod_scale_up_delay", b"new_pod_scale_up_delay", "ok_total_unready_count", b"ok_total_unready_count", "scale_down_delay_after_add", b"scale_down_delay_after_add", "scale_down_delay_after_delete", b"scale_down_delay_after_delete", "scale_down_delay_after_failure", b"scale_down_delay_after_failure", "scale_down_unneeded_time", b"scale_down_unneeded_time", "scale_down_unready_time", b"scale_down_unready_time", "scale_down_utilization_threshold", b"scale_down_utilization_threshold", "scan_interval", b"scan_interval", "skip_nodes_with_local_storage", b"skip_nodes_with_local_storage", "skip_nodes_with_system_pods", b"skip_nodes_with_system_pods"]) -> None: ...

global___ManagedClusterPropertiesAutoScalerProfile = ManagedClusterPropertiesAutoScalerProfile

@typing_extensions.final
class ManagedClusterAPIServerAccessProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHORIZED_IP_RANGES_FIELD_NUMBER: builtins.int
    DISABLE_RUN_COMMAND_FIELD_NUMBER: builtins.int
    ENABLE_PRIVATE_CLUSTER_FIELD_NUMBER: builtins.int
    ENABLE_PRIVATE_CLUSTER_PUBLIC_FQDN_FIELD_NUMBER: builtins.int
    PRIVATE_DNS_ZONE_FIELD_NUMBER: builtins.int
    @property
    def authorized_ip_ranges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    disable_run_command: builtins.bool
    enable_private_cluster: builtins.bool
    enable_private_cluster_public_fqdn: builtins.bool
    private_dns_zone: builtins.str
    def __init__(
        self,
        *,
        authorized_ip_ranges: collections.abc.Iterable[builtins.str] | None = ...,
        disable_run_command: builtins.bool = ...,
        enable_private_cluster: builtins.bool = ...,
        enable_private_cluster_public_fqdn: builtins.bool = ...,
        private_dns_zone: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["authorized_ip_ranges", b"authorized_ip_ranges", "disable_run_command", b"disable_run_command", "enable_private_cluster", b"enable_private_cluster", "enable_private_cluster_public_fqdn", b"enable_private_cluster_public_fqdn", "private_dns_zone", b"private_dns_zone"]) -> None: ...

global___ManagedClusterAPIServerAccessProfile = ManagedClusterAPIServerAccessProfile

@typing_extensions.final
class ManagedClusterAgentPoolProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class NodeLabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    AVAILABILITY_ZONES_FIELD_NUMBER: builtins.int
    CAPACITY_RESERVATION_GROUP_ID_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    CREATION_DATA_FIELD_NUMBER: builtins.int
    ENABLE_AUTO_SCALING_FIELD_NUMBER: builtins.int
    ENABLE_ENCRYPTION_AT_HOST_FIELD_NUMBER: builtins.int
    ENABLE_FIPS_FIELD_NUMBER: builtins.int
    ENABLE_NODE_PUBLIC_IP_FIELD_NUMBER: builtins.int
    ENABLE_ULTRA_SSD_FIELD_NUMBER: builtins.int
    GPU_INSTANCE_PROFILE_FIELD_NUMBER: builtins.int
    HOST_GROUP_ID_FIELD_NUMBER: builtins.int
    KUBELET_CONFIG_FIELD_NUMBER: builtins.int
    KUBELET_DISK_TYPE_FIELD_NUMBER: builtins.int
    LINUX_OS_CONFIG_FIELD_NUMBER: builtins.int
    MAX_COUNT_FIELD_NUMBER: builtins.int
    MAX_PODS_FIELD_NUMBER: builtins.int
    MESSAGE_OF_THE_DAY_FIELD_NUMBER: builtins.int
    MIN_COUNT_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NODE_LABELS_FIELD_NUMBER: builtins.int
    NODE_PUBLIC_IP_PREFIX_ID_FIELD_NUMBER: builtins.int
    NODE_TAINTS_FIELD_NUMBER: builtins.int
    ORCHESTRATOR_VERSION_FIELD_NUMBER: builtins.int
    OS_DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    OS_DISK_TYPE_FIELD_NUMBER: builtins.int
    OS_SKU_FIELD_NUMBER: builtins.int
    OS_TYPE_FIELD_NUMBER: builtins.int
    POD_SUBNET_ID_FIELD_NUMBER: builtins.int
    POWER_STATE_FIELD_NUMBER: builtins.int
    PROXIMITY_PLACEMENT_GROUP_ID_FIELD_NUMBER: builtins.int
    SCALE_DOWN_MODE_FIELD_NUMBER: builtins.int
    SCALE_SET_EVICTION_POLICY_FIELD_NUMBER: builtins.int
    SCALE_SET_PRIORITY_FIELD_NUMBER: builtins.int
    SPOT_MAX_PRICE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    UPGRADE_SETTINGS_FIELD_NUMBER: builtins.int
    VM_SIZE_FIELD_NUMBER: builtins.int
    VNET_SUBNET_ID_FIELD_NUMBER: builtins.int
    WORKLOAD_RUNTIME_FIELD_NUMBER: builtins.int
    @property
    def availability_zones(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    capacity_reservation_group_id: builtins.str
    count: builtins.int
    @property
    def creation_data(self) -> global___CreationData: ...
    enable_auto_scaling: builtins.bool
    enable_encryption_at_host: builtins.bool
    enable_fips: builtins.bool
    enable_node_public_ip: builtins.bool
    enable_ultra_ssd: builtins.bool
    gpu_instance_profile: builtins.str
    host_group_id: builtins.str
    @property
    def kubelet_config(self) -> global___KubeletConfig: ...
    kubelet_disk_type: builtins.str
    @property
    def linux_os_config(self) -> global___LinuxOSConfig: ...
    max_count: builtins.int
    max_pods: builtins.int
    message_of_the_day: builtins.str
    min_count: builtins.int
    mode: builtins.str
    name: builtins.str
    @property
    def node_labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    node_public_ip_prefix_id: builtins.str
    @property
    def node_taints(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    orchestrator_version: builtins.str
    os_disk_size_gb: builtins.int
    os_disk_type: builtins.str
    os_sku: builtins.str
    os_type: builtins.str
    pod_subnet_id: builtins.str
    @property
    def power_state(self) -> global___PowerState: ...
    proximity_placement_group_id: builtins.str
    scale_down_mode: builtins.str
    scale_set_eviction_policy: builtins.str
    scale_set_priority: builtins.str
    spot_max_price: builtins.float
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    type: builtins.str
    @property
    def upgrade_settings(self) -> global___AgentPoolUpgradeSettings: ...
    vm_size: builtins.str
    vnet_subnet_id: builtins.str
    workload_runtime: builtins.str
    def __init__(
        self,
        *,
        availability_zones: collections.abc.Iterable[builtins.str] | None = ...,
        capacity_reservation_group_id: builtins.str = ...,
        count: builtins.int = ...,
        creation_data: global___CreationData | None = ...,
        enable_auto_scaling: builtins.bool = ...,
        enable_encryption_at_host: builtins.bool = ...,
        enable_fips: builtins.bool = ...,
        enable_node_public_ip: builtins.bool = ...,
        enable_ultra_ssd: builtins.bool = ...,
        gpu_instance_profile: builtins.str = ...,
        host_group_id: builtins.str = ...,
        kubelet_config: global___KubeletConfig | None = ...,
        kubelet_disk_type: builtins.str = ...,
        linux_os_config: global___LinuxOSConfig | None = ...,
        max_count: builtins.int = ...,
        max_pods: builtins.int = ...,
        message_of_the_day: builtins.str = ...,
        min_count: builtins.int = ...,
        mode: builtins.str = ...,
        name: builtins.str = ...,
        node_labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        node_public_ip_prefix_id: builtins.str = ...,
        node_taints: collections.abc.Iterable[builtins.str] | None = ...,
        orchestrator_version: builtins.str = ...,
        os_disk_size_gb: builtins.int = ...,
        os_disk_type: builtins.str = ...,
        os_sku: builtins.str = ...,
        os_type: builtins.str = ...,
        pod_subnet_id: builtins.str = ...,
        power_state: global___PowerState | None = ...,
        proximity_placement_group_id: builtins.str = ...,
        scale_down_mode: builtins.str = ...,
        scale_set_eviction_policy: builtins.str = ...,
        scale_set_priority: builtins.str = ...,
        spot_max_price: builtins.float = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        type: builtins.str = ...,
        upgrade_settings: global___AgentPoolUpgradeSettings | None = ...,
        vm_size: builtins.str = ...,
        vnet_subnet_id: builtins.str = ...,
        workload_runtime: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["creation_data", b"creation_data", "kubelet_config", b"kubelet_config", "linux_os_config", b"linux_os_config", "power_state", b"power_state", "upgrade_settings", b"upgrade_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["availability_zones", b"availability_zones", "capacity_reservation_group_id", b"capacity_reservation_group_id", "count", b"count", "creation_data", b"creation_data", "enable_auto_scaling", b"enable_auto_scaling", "enable_encryption_at_host", b"enable_encryption_at_host", "enable_fips", b"enable_fips", "enable_node_public_ip", b"enable_node_public_ip", "enable_ultra_ssd", b"enable_ultra_ssd", "gpu_instance_profile", b"gpu_instance_profile", "host_group_id", b"host_group_id", "kubelet_config", b"kubelet_config", "kubelet_disk_type", b"kubelet_disk_type", "linux_os_config", b"linux_os_config", "max_count", b"max_count", "max_pods", b"max_pods", "message_of_the_day", b"message_of_the_day", "min_count", b"min_count", "mode", b"mode", "name", b"name", "node_labels", b"node_labels", "node_public_ip_prefix_id", b"node_public_ip_prefix_id", "node_taints", b"node_taints", "orchestrator_version", b"orchestrator_version", "os_disk_size_gb", b"os_disk_size_gb", "os_disk_type", b"os_disk_type", "os_sku", b"os_sku", "os_type", b"os_type", "pod_subnet_id", b"pod_subnet_id", "power_state", b"power_state", "proximity_placement_group_id", b"proximity_placement_group_id", "scale_down_mode", b"scale_down_mode", "scale_set_eviction_policy", b"scale_set_eviction_policy", "scale_set_priority", b"scale_set_priority", "spot_max_price", b"spot_max_price", "tags", b"tags", "type", b"type", "upgrade_settings", b"upgrade_settings", "vm_size", b"vm_size", "vnet_subnet_id", b"vnet_subnet_id", "workload_runtime", b"workload_runtime"]) -> None: ...

global___ManagedClusterAgentPoolProfile = ManagedClusterAgentPoolProfile

@typing_extensions.final
class AgentPoolUpgradeSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_SURGE_FIELD_NUMBER: builtins.int
    max_surge: builtins.str
    def __init__(
        self,
        *,
        max_surge: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_surge", b"max_surge"]) -> None: ...

global___AgentPoolUpgradeSettings = AgentPoolUpgradeSettings

@typing_extensions.final
class PowerState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    code: builtins.str
    def __init__(
        self,
        *,
        code: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code"]) -> None: ...

global___PowerState = PowerState

@typing_extensions.final
class LinuxOSConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SWAP_FILE_SIZE_MB_FIELD_NUMBER: builtins.int
    SYSCTLS_FIELD_NUMBER: builtins.int
    TRANSPARENT_HUGE_PAGE_DEFRAG_FIELD_NUMBER: builtins.int
    TRANSPARENT_HUGE_PAGE_ENABLED_FIELD_NUMBER: builtins.int
    swap_file_size_mb: builtins.int
    @property
    def sysctls(self) -> global___SysctlConfig: ...
    transparent_huge_page_defrag: builtins.str
    transparent_huge_page_enabled: builtins.str
    def __init__(
        self,
        *,
        swap_file_size_mb: builtins.int = ...,
        sysctls: global___SysctlConfig | None = ...,
        transparent_huge_page_defrag: builtins.str = ...,
        transparent_huge_page_enabled: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["sysctls", b"sysctls"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["swap_file_size_mb", b"swap_file_size_mb", "sysctls", b"sysctls", "transparent_huge_page_defrag", b"transparent_huge_page_defrag", "transparent_huge_page_enabled", b"transparent_huge_page_enabled"]) -> None: ...

global___LinuxOSConfig = LinuxOSConfig

@typing_extensions.final
class SysctlConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FS_AIO_MAX_NR_FIELD_NUMBER: builtins.int
    FS_FILE_MAX_FIELD_NUMBER: builtins.int
    FS_INOTIFY_MAX_USER_WATCHES_FIELD_NUMBER: builtins.int
    FS_NR_OPEN_FIELD_NUMBER: builtins.int
    KERNEL_THREADS_MAX_FIELD_NUMBER: builtins.int
    NET_CORE_NETDEV_MAX_BACKLOG_FIELD_NUMBER: builtins.int
    NET_CORE_OPTMEM_MAX_FIELD_NUMBER: builtins.int
    NET_CORE_RMEM_DEFAULT_FIELD_NUMBER: builtins.int
    NET_CORE_RMEM_MAX_FIELD_NUMBER: builtins.int
    NET_CORE_SOMAXCONN_FIELD_NUMBER: builtins.int
    NET_CORE_WMEM_DEFAULT_FIELD_NUMBER: builtins.int
    NET_CORE_WMEM_MAX_FIELD_NUMBER: builtins.int
    NET_IPV4_IP_LOCAL_PORT_RANGE_FIELD_NUMBER: builtins.int
    NET_IPV4_NEIGH_DEFAULT_GC_THRESH1_FIELD_NUMBER: builtins.int
    NET_IPV4_NEIGH_DEFAULT_GC_THRESH2_FIELD_NUMBER: builtins.int
    NET_IPV4_NEIGH_DEFAULT_GC_THRESH3_FIELD_NUMBER: builtins.int
    NET_IPV4_TCP_FIN_TIMEOUT_FIELD_NUMBER: builtins.int
    NET_IPV4_TCPKEEPALIVE_INTVL_FIELD_NUMBER: builtins.int
    NET_IPV4_TCP_KEEPALIVE_PROBES_FIELD_NUMBER: builtins.int
    NET_IPV4_TCP_KEEPALIVE_TIME_FIELD_NUMBER: builtins.int
    NET_IPV4_TCP_MAX_SYN_BACKLOG_FIELD_NUMBER: builtins.int
    NET_IPV4_TCP_MAX_TW_BUCKETS_FIELD_NUMBER: builtins.int
    NET_IPV4_TCP_TW_REUSE_FIELD_NUMBER: builtins.int
    NET_NETFILTER_NF_CONNTRACK_BUCKETS_FIELD_NUMBER: builtins.int
    NET_NETFILTER_NF_CONNTRACK_MAX_FIELD_NUMBER: builtins.int
    VM_MAX_MAP_COUNT_FIELD_NUMBER: builtins.int
    VM_SWAPPINESS_FIELD_NUMBER: builtins.int
    VM_VFS_CACHE_PRESSURE_FIELD_NUMBER: builtins.int
    fs_aio_max_nr: builtins.int
    fs_file_max: builtins.int
    fs_inotify_max_user_watches: builtins.int
    fs_nr_open: builtins.int
    kernel_threads_max: builtins.int
    net_core_netdev_max_backlog: builtins.int
    net_core_optmem_max: builtins.int
    net_core_rmem_default: builtins.int
    net_core_rmem_max: builtins.int
    net_core_somaxconn: builtins.int
    net_core_wmem_default: builtins.int
    net_core_wmem_max: builtins.int
    net_ipv4_ip_local_port_range: builtins.str
    net_ipv4_neigh_default_gc_thresh1: builtins.int
    net_ipv4_neigh_default_gc_thresh2: builtins.int
    net_ipv4_neigh_default_gc_thresh3: builtins.int
    net_ipv4_tcp_fin_timeout: builtins.int
    net_ipv4_tcpkeepalive_intvl: builtins.int
    net_ipv4_tcp_keepalive_probes: builtins.int
    net_ipv4_tcp_keepalive_time: builtins.int
    net_ipv4_tcp_max_syn_backlog: builtins.int
    net_ipv4_tcp_max_tw_buckets: builtins.int
    net_ipv4_tcp_tw_reuse: builtins.bool
    net_netfilter_nf_conntrack_buckets: builtins.int
    net_netfilter_nf_conntrack_max: builtins.int
    vm_max_map_count: builtins.int
    vm_swappiness: builtins.int
    vm_vfs_cache_pressure: builtins.int
    def __init__(
        self,
        *,
        fs_aio_max_nr: builtins.int = ...,
        fs_file_max: builtins.int = ...,
        fs_inotify_max_user_watches: builtins.int = ...,
        fs_nr_open: builtins.int = ...,
        kernel_threads_max: builtins.int = ...,
        net_core_netdev_max_backlog: builtins.int = ...,
        net_core_optmem_max: builtins.int = ...,
        net_core_rmem_default: builtins.int = ...,
        net_core_rmem_max: builtins.int = ...,
        net_core_somaxconn: builtins.int = ...,
        net_core_wmem_default: builtins.int = ...,
        net_core_wmem_max: builtins.int = ...,
        net_ipv4_ip_local_port_range: builtins.str = ...,
        net_ipv4_neigh_default_gc_thresh1: builtins.int = ...,
        net_ipv4_neigh_default_gc_thresh2: builtins.int = ...,
        net_ipv4_neigh_default_gc_thresh3: builtins.int = ...,
        net_ipv4_tcp_fin_timeout: builtins.int = ...,
        net_ipv4_tcpkeepalive_intvl: builtins.int = ...,
        net_ipv4_tcp_keepalive_probes: builtins.int = ...,
        net_ipv4_tcp_keepalive_time: builtins.int = ...,
        net_ipv4_tcp_max_syn_backlog: builtins.int = ...,
        net_ipv4_tcp_max_tw_buckets: builtins.int = ...,
        net_ipv4_tcp_tw_reuse: builtins.bool = ...,
        net_netfilter_nf_conntrack_buckets: builtins.int = ...,
        net_netfilter_nf_conntrack_max: builtins.int = ...,
        vm_max_map_count: builtins.int = ...,
        vm_swappiness: builtins.int = ...,
        vm_vfs_cache_pressure: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fs_aio_max_nr", b"fs_aio_max_nr", "fs_file_max", b"fs_file_max", "fs_inotify_max_user_watches", b"fs_inotify_max_user_watches", "fs_nr_open", b"fs_nr_open", "kernel_threads_max", b"kernel_threads_max", "net_core_netdev_max_backlog", b"net_core_netdev_max_backlog", "net_core_optmem_max", b"net_core_optmem_max", "net_core_rmem_default", b"net_core_rmem_default", "net_core_rmem_max", b"net_core_rmem_max", "net_core_somaxconn", b"net_core_somaxconn", "net_core_wmem_default", b"net_core_wmem_default", "net_core_wmem_max", b"net_core_wmem_max", "net_ipv4_ip_local_port_range", b"net_ipv4_ip_local_port_range", "net_ipv4_neigh_default_gc_thresh1", b"net_ipv4_neigh_default_gc_thresh1", "net_ipv4_neigh_default_gc_thresh2", b"net_ipv4_neigh_default_gc_thresh2", "net_ipv4_neigh_default_gc_thresh3", b"net_ipv4_neigh_default_gc_thresh3", "net_ipv4_tcp_fin_timeout", b"net_ipv4_tcp_fin_timeout", "net_ipv4_tcp_keepalive_probes", b"net_ipv4_tcp_keepalive_probes", "net_ipv4_tcp_keepalive_time", b"net_ipv4_tcp_keepalive_time", "net_ipv4_tcp_max_syn_backlog", b"net_ipv4_tcp_max_syn_backlog", "net_ipv4_tcp_max_tw_buckets", b"net_ipv4_tcp_max_tw_buckets", "net_ipv4_tcp_tw_reuse", b"net_ipv4_tcp_tw_reuse", "net_ipv4_tcpkeepalive_intvl", b"net_ipv4_tcpkeepalive_intvl", "net_netfilter_nf_conntrack_buckets", b"net_netfilter_nf_conntrack_buckets", "net_netfilter_nf_conntrack_max", b"net_netfilter_nf_conntrack_max", "vm_max_map_count", b"vm_max_map_count", "vm_swappiness", b"vm_swappiness", "vm_vfs_cache_pressure", b"vm_vfs_cache_pressure"]) -> None: ...

global___SysctlConfig = SysctlConfig

@typing_extensions.final
class KubeletConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_UNSAFE_SYSCTLS_FIELD_NUMBER: builtins.int
    CONTAINER_LOG_MAX_FILES_FIELD_NUMBER: builtins.int
    CONTAINER_LOG_MAX_SIZE_MB_FIELD_NUMBER: builtins.int
    CPU_CFS_QUOTA_FIELD_NUMBER: builtins.int
    CPU_CFS_QUOTA_PERIOD_FIELD_NUMBER: builtins.int
    CPU_MANAGER_POLICY_FIELD_NUMBER: builtins.int
    FAIL_SWAP_ON_FIELD_NUMBER: builtins.int
    IMAGE_GC_HIGH_THRESHOLD_FIELD_NUMBER: builtins.int
    IMAGE_GC_LOW_THRESHOLD_FIELD_NUMBER: builtins.int
    POD_MAX_PIDS_FIELD_NUMBER: builtins.int
    TOPOLOGY_MANAGER_POLICY_FIELD_NUMBER: builtins.int
    @property
    def allowed_unsafe_sysctls(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    container_log_max_files: builtins.int
    container_log_max_size_mb: builtins.int
    cpu_cfs_quota: builtins.bool
    cpu_cfs_quota_period: builtins.str
    cpu_manager_policy: builtins.str
    fail_swap_on: builtins.bool
    image_gc_high_threshold: builtins.int
    image_gc_low_threshold: builtins.int
    pod_max_pids: builtins.int
    topology_manager_policy: builtins.str
    def __init__(
        self,
        *,
        allowed_unsafe_sysctls: collections.abc.Iterable[builtins.str] | None = ...,
        container_log_max_files: builtins.int = ...,
        container_log_max_size_mb: builtins.int = ...,
        cpu_cfs_quota: builtins.bool = ...,
        cpu_cfs_quota_period: builtins.str = ...,
        cpu_manager_policy: builtins.str = ...,
        fail_swap_on: builtins.bool = ...,
        image_gc_high_threshold: builtins.int = ...,
        image_gc_low_threshold: builtins.int = ...,
        pod_max_pids: builtins.int = ...,
        topology_manager_policy: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_unsafe_sysctls", b"allowed_unsafe_sysctls", "container_log_max_files", b"container_log_max_files", "container_log_max_size_mb", b"container_log_max_size_mb", "cpu_cfs_quota", b"cpu_cfs_quota", "cpu_cfs_quota_period", b"cpu_cfs_quota_period", "cpu_manager_policy", b"cpu_manager_policy", "fail_swap_on", b"fail_swap_on", "image_gc_high_threshold", b"image_gc_high_threshold", "image_gc_low_threshold", b"image_gc_low_threshold", "pod_max_pids", b"pod_max_pids", "topology_manager_policy", b"topology_manager_policy"]) -> None: ...

global___KubeletConfig = KubeletConfig

@typing_extensions.final
class CreationData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_RESOURCE_ID_FIELD_NUMBER: builtins.int
    source_resource_id: builtins.str
    def __init__(
        self,
        *,
        source_resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["source_resource_id", b"source_resource_id"]) -> None: ...

global___CreationData = CreationData

@typing_extensions.final
class ManagedClusterAADProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADMIN_GROUP_OBJECT_IDS_FIELD_NUMBER: builtins.int
    CLIENT_APP_ID_FIELD_NUMBER: builtins.int
    ENABLE_AZURE_RBAC_FIELD_NUMBER: builtins.int
    MANAGED_FIELD_NUMBER: builtins.int
    SERVER_APP_ID_FIELD_NUMBER: builtins.int
    SERVER_APP_SECRET_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    @property
    def admin_group_object_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    client_app_id: builtins.str
    enable_azure_rbac: builtins.bool
    managed: builtins.bool
    server_app_id: builtins.str
    server_app_secret: builtins.str
    tenant_id: builtins.str
    def __init__(
        self,
        *,
        admin_group_object_ids: collections.abc.Iterable[builtins.str] | None = ...,
        client_app_id: builtins.str = ...,
        enable_azure_rbac: builtins.bool = ...,
        managed: builtins.bool = ...,
        server_app_id: builtins.str = ...,
        server_app_secret: builtins.str = ...,
        tenant_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["admin_group_object_ids", b"admin_group_object_ids", "client_app_id", b"client_app_id", "enable_azure_rbac", b"enable_azure_rbac", "managed", b"managed", "server_app_id", b"server_app_id", "server_app_secret", b"server_app_secret", "tenant_id", b"tenant_id"]) -> None: ...

global___ManagedClusterAADProfile = ManagedClusterAADProfile

@typing_extensions.final
class ManagedClusterIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___ManagedClusterIdentity = ManagedClusterIdentity

@typing_extensions.final
class ExtendedLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "type", b"type"]) -> None: ...

global___ExtendedLocation = ExtendedLocation



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import gcp.gcp_pubsub_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GooglePubsub(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBSUB_SCHEMA_FIELD_NUMBER: builtins.int
    PUBSUB_SUBSCRIPTION_FIELD_NUMBER: builtins.int
    PUBSUB_SUBSCRIPTION_IAM_BINDING_FIELD_NUMBER: builtins.int
    PUBSUB_SUBSCRIPTION_IAM_MEMBER_FIELD_NUMBER: builtins.int
    PUBSUB_SUBSCRIPTION_IAM_POLICY_FIELD_NUMBER: builtins.int
    PUBSUB_TOPIC_FIELD_NUMBER: builtins.int
    PUBSUB_TOPIC_IAM_BINDING_FIELD_NUMBER: builtins.int
    PUBSUB_TOPIC_IAM_MEMBER_FIELD_NUMBER: builtins.int
    PUBSUB_TOPIC_IAM_POLICY_FIELD_NUMBER: builtins.int
    @property
    def pubsub_schema(self) -> gcp.gcp_pubsub_pb2.PubsubSchema: ...
    @property
    def pubsub_subscription(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_pubsub_pb2.PubsubSubscription]: ...
    @property
    def pubsub_subscription_iam_binding(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_pubsub_pb2.PubsubSubscriptionIamBinding]: ...
    @property
    def pubsub_subscription_iam_member(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_pubsub_pb2.PubsubSubscriptionIamMember]: ...
    @property
    def pubsub_subscription_iam_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_pubsub_pb2.PubsubSubscriptionIamPolicy]: ...
    @property
    def pubsub_topic(self) -> gcp.gcp_pubsub_pb2.PubsubTopic: ...
    @property
    def pubsub_topic_iam_binding(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_pubsub_pb2.PubsubTopicIamBinding]: ...
    @property
    def pubsub_topic_iam_member(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_pubsub_pb2.PubsubTopicIamMember]: ...
    @property
    def pubsub_topic_iam_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_pubsub_pb2.PubsubTopicIamPolicy]: ...
    def __init__(
        self,
        *,
        pubsub_schema: gcp.gcp_pubsub_pb2.PubsubSchema | None = ...,
        pubsub_subscription: collections.abc.Iterable[gcp.gcp_pubsub_pb2.PubsubSubscription] | None = ...,
        pubsub_subscription_iam_binding: collections.abc.Iterable[gcp.gcp_pubsub_pb2.PubsubSubscriptionIamBinding] | None = ...,
        pubsub_subscription_iam_member: collections.abc.Iterable[gcp.gcp_pubsub_pb2.PubsubSubscriptionIamMember] | None = ...,
        pubsub_subscription_iam_policy: collections.abc.Iterable[gcp.gcp_pubsub_pb2.PubsubSubscriptionIamPolicy] | None = ...,
        pubsub_topic: gcp.gcp_pubsub_pb2.PubsubTopic | None = ...,
        pubsub_topic_iam_binding: collections.abc.Iterable[gcp.gcp_pubsub_pb2.PubsubTopicIamBinding] | None = ...,
        pubsub_topic_iam_member: collections.abc.Iterable[gcp.gcp_pubsub_pb2.PubsubTopicIamMember] | None = ...,
        pubsub_topic_iam_policy: collections.abc.Iterable[gcp.gcp_pubsub_pb2.PubsubTopicIamPolicy] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pubsub_schema", b"pubsub_schema", "pubsub_topic", b"pubsub_topic"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pubsub_schema", b"pubsub_schema", "pubsub_subscription", b"pubsub_subscription", "pubsub_subscription_iam_binding", b"pubsub_subscription_iam_binding", "pubsub_subscription_iam_member", b"pubsub_subscription_iam_member", "pubsub_subscription_iam_policy", b"pubsub_subscription_iam_policy", "pubsub_topic", b"pubsub_topic", "pubsub_topic_iam_binding", b"pubsub_topic_iam_binding", "pubsub_topic_iam_member", b"pubsub_topic_iam_member", "pubsub_topic_iam_policy", b"pubsub_topic_iam_policy"]) -> None: ...

global___GooglePubsub = GooglePubsub



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_aad.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x61zure/azure_microsoft_aad.proto\x12\x1foak9.tython.azure.microsoft_aad\x1a\x13shared/shared.proto\"Y\n\rMicrosoft_AAD\x12H\n\x0f\x64omain_services\x18\x01 \x03(\x0b\x32/.oak9.tython.azure.microsoft_aad.DomainServices\"\x97\x01\n\x19\x44omainServicesOuContainer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08password\x18\x04 \x01(\t\x12\x0b\n\x03spn\x18\x05 \x01(\t\"\xc2\x06\n\x0e\x44omainServices\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12!\n\x19\x64omain_configuration_type\x18\x05 \x01(\t\x12\x13\n\x0b\x64omain_name\x18\x06 \x01(\t\x12Y\n\x18\x64omain_security_settings\x18\x07 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_aad.DomainSecuritySettings\x12\x15\n\rfiltered_sync\x18\x08 \x01(\t\x12\x46\n\x0eldaps_settings\x18\t \x01(\x0b\x32..oak9.tython.azure.microsoft_aad.LdapsSettings\x12T\n\x15notification_settings\x18\n \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_aad.NotificationSettings\x12\x41\n\x0creplica_sets\x18\x0b \x03(\x0b\x32+.oak9.tython.azure.microsoft_aad.ReplicaSet\x12Y\n\x18resource_forest_settings\x18\x0c \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_aad.ResourceForestSettings\x12\x0b\n\x03sku\x18\r \x01(\t\x12G\n\x04tags\x18\x0e \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_aad.DomainServices.TagsEntry\x12`\n\x1c\x64omain_services_ou_container\x18\x0f \x03(\x0b\x32:.oak9.tython.azure.microsoft_aad.DomainServicesOuContainer\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"q\n\x16ResourceForestSettings\x12\x17\n\x0fresource_forest\x18\x01 \x01(\t\x12>\n\x08settings\x18\x02 \x03(\x0b\x32,.oak9.tython.azure.microsoft_aad.ForestTrust\"\x8a\x01\n\x0b\x46orestTrust\x12\x15\n\rfriendly_name\x18\x01 \x01(\t\x12\x16\n\x0eremote_dns_ips\x18\x02 \x01(\t\x12\x17\n\x0ftrust_direction\x18\x03 \x01(\t\x12\x1b\n\x13trusted_domain_fqdn\x18\x04 \x01(\t\x12\x16\n\x0etrust_password\x18\x05 \x01(\t\"1\n\nReplicaSet\x12\x10\n\x08location\x18\x01 \x01(\t\x12\x11\n\tsubnet_id\x18\x02 \x01(\t\"m\n\x14NotificationSettings\x12\x1d\n\x15\x61\x64\x64itional_recipients\x18\x01 \x03(\t\x12\x18\n\x10notify_dc_admins\x18\x02 \x01(\t\x12\x1c\n\x14notify_global_admins\x18\x03 \x01(\t\"r\n\rLdapsSettings\x12\x17\n\x0f\x65xternal_access\x18\x01 \x01(\t\x12\r\n\x05ldaps\x18\x02 \x01(\t\x12\x17\n\x0fpfx_certificate\x18\x03 \x01(\t\x12 \n\x18pfx_certificate_password\x18\x04 \x01(\t\"\xd3\x01\n\x16\x44omainSecuritySettings\x12\x19\n\x11kerberos_armoring\x18\x01 \x01(\t\x12\x1f\n\x17kerberos_rc4_encryption\x18\x02 \x01(\t\x12\x0f\n\x07ntlm_v1\x18\x03 \x01(\t\x12\x1f\n\x17sync_kerberos_passwords\x18\x04 \x01(\t\x12\x1b\n\x13sync_ntlm_passwords\x18\x05 \x01(\t\x12\x1e\n\x16sync_on_prem_passwords\x18\x06 \x01(\t\x12\x0e\n\x06tls_v1\x18\x07 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_aad_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DOMAINSERVICES_TAGSENTRY._options = None
  _DOMAINSERVICES_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_AAD._serialized_start=89
  _MICROSOFT_AAD._serialized_end=178
  _DOMAINSERVICESOUCONTAINER._serialized_start=181
  _DOMAINSERVICESOUCONTAINER._serialized_end=332
  _DOMAINSERVICES._serialized_start=335
  _DOMAINSERVICES._serialized_end=1169
  _DOMAINSERVICES_TAGSENTRY._serialized_start=1126
  _DOMAINSERVICES_TAGSENTRY._serialized_end=1169
  _RESOURCEFORESTSETTINGS._serialized_start=1171
  _RESOURCEFORESTSETTINGS._serialized_end=1284
  _FORESTTRUST._serialized_start=1287
  _FORESTTRUST._serialized_end=1425
  _REPLICASET._serialized_start=1427
  _REPLICASET._serialized_end=1476
  _NOTIFICATIONSETTINGS._serialized_start=1478
  _NOTIFICATIONSETTINGS._serialized_end=1587
  _LDAPSSETTINGS._serialized_start=1589
  _LDAPSSETTINGS._serialized_end=1703
  _DOMAINSECURITYSETTINGS._serialized_start=1706
  _DOMAINSECURITYSETTINGS._serialized_end=1917
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AnalyzerFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONTAINS_FIELD_NUMBER: builtins.int
    EQ_FIELD_NUMBER: builtins.int
    EXISTS_FIELD_NUMBER: builtins.int
    PROPERTY_FIELD_NUMBER: builtins.int
    NEQ_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def contains(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def eq(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    exists: builtins.bool
    property: builtins.str
    @property
    def neq(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        contains: collections.abc.Iterable[builtins.str] | None = ...,
        eq: collections.abc.Iterable[builtins.str] | None = ...,
        exists: builtins.bool = ...,
        property: builtins.str = ...,
        neq: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["contains", b"contains", "eq", b"eq", "exists", b"exists", "neq", b"neq", "property", b"property", "resource_info", b"resource_info"]) -> None: ...

global___AnalyzerFilter = AnalyzerFilter

@typing_extensions.final
class AnalyzerArchiveRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    RULE_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def filter(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AnalyzerFilter]: ...
    rule_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        filter: collections.abc.Iterable[global___AnalyzerFilter] | None = ...,
        rule_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["filter", b"filter", "resource_info", b"resource_info", "rule_name", b"rule_name"]) -> None: ...

global___AnalyzerArchiveRule = AnalyzerArchiveRule

@typing_extensions.final
class Analyzer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ANALYZER_NAME_FIELD_NUMBER: builtins.int
    ARCHIVE_RULES_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    analyzer_name: builtins.str
    @property
    def archive_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AnalyzerArchiveRule]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        analyzer_name: builtins.str = ...,
        archive_rules: collections.abc.Iterable[global___AnalyzerArchiveRule] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["analyzer_name", b"analyzer_name", "archive_rules", b"archive_rules", "resource_info", b"resource_info", "tags", b"tags", "type", b"type"]) -> None: ...

global___Analyzer = Analyzer

@typing_extensions.final
class AccessAnalyzer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ANALYZER_FIELD_NUMBER: builtins.int
    @property
    def analyzer(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Analyzer]: ...
    def __init__(
        self,
        *,
        analyzer: collections.abc.Iterable[global___Analyzer] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["analyzer", b"analyzer"]) -> None: ...

global___AccessAnalyzer = AccessAnalyzer
